pub struct Raw<T>(pub T);Expand description
Wrapper to render content using Display without escaping.
Use this wrapper when you have HTML content that is already safe and should be rendered without escaping. This should generally only be used for trusted content, not for user-provided input.
Example
use gen_html::{html, Raw};
let oopsie = html! {
p { (Raw("<div>")) }
};Tuple Fields
0: TTrait Implementations
impl<T: Copy> Copy for Raw<T>